<?php

namespace OneSender\Uncanny\Modules\Admin;

defined('ABSPATH') or die('No direct access allowed to this file');

use OneSender\Uncanny\Repository;

class Admin_Menu {

     public static function init() {
         $class = new static();
    }

    public function __construct() {
        add_action( 'admin_enqueue_scripts', array( $this, 'admin_scripts' ) );

        add_action( 'admin_menu', array( $this, 'add_menu_page' ) );

        if( !Repository::instance()->is_activated() ) {
            add_action( 'admin_head', array( $this, 'activation_header_css' ) );
        }
    }

    public function add_menu_page() {
        add_menu_page(
            'OneSender UA',
            'OneSender UA',
            'manage_options',
            'osun',
            array( $this, 'render_dashboard' ),
            OSUN_URL . 'assets/img/menu-logo.svg',
            3
        );

        add_submenu_page( 'osun', 'Setting', 'Setting', 'manage_options', 'osun',
            array($this, 'render_dashboard') );


    }

    public function render_dashboard() {
        if( Repository::instance()->is_activated() ) {
            echo '<div id="osunapp" class="osapp"></div>';
        } else {
            echo '<div id="osactivation" class="osapp"></div>';
        }
    }


    public function admin_scripts( $hook ) {
        $pages = osun_collect(['toplevel_page_osun']);

        if ( ! $pages->hasValue( $hook ) ) return;

        if( Repository::instance()->is_activated() ) {

            wp_enqueue_style( 'osun-dashboard', OSUN_URL . 'assets/dashboard/dashboard.css', array(), OSUN_VERSION );
            wp_enqueue_script( 'osun-dashboard', OSUN_URL . 'assets/dashboard/dashboard.js', array(), OSUN_VERSION, true );
            
            $hook = str_replace( ['toplevel_page_', 'onesender_page_'], '', $hook );
            wp_localize_script( 'osun-dashboard', '__OSAPP',
                array(
                    'ajaxurl' => admin_url( 'admin-ajax.php' ),
                    'prefix' => 'osun_',
                    'hook' => $hook,
                    'page' => 'home',
                    'version' => OSUN_VERSION,
                    'apikey' => '',
                    'nonce' => wp_create_nonce()
                )
            );

        } else {

            wp_enqueue_script( 'osun-activate', OSUN_URL . 'assets/js/activate.js', array(), OSUN_VERSION, true );
            
            $hook = str_replace( ['toplevel_page_', 'onesender_page_'], '', $hook );
            wp_localize_script( 'osun-activate', '__OSACTIVATE',
                array(
                    'ajaxurl' => admin_url( 'admin-ajax.php' ),
                    'prefix' => 'osunp_',
                    'hook' => $hook,
                    'nonce' => wp_create_nonce()
                )
            );
        }

    }

    public function activation_header_css() {
        echo '<style type="text/css">
.osa *{box-sizing:border-box;font-size:15px;line-height:1.5}.osa{background:rgb(255,255,255);border:1px solid rgba(100,100,100,.2);border-radius:4px;max-width:480px;margin:5vh auto;overflow:hidden}.osa #email{padding-left:32px}.osa .bg-email{position:relative}.osa .bg-email:after{content:"\f466";color:#8c8f94;font-family:dashicons;line-height:1;font-weight:400;font-style:normal;text-transform:none;text-rendering:auto;font-size:18px;text-align:center;position:absolute;left:8px;top:8px;height:17px;width:20px}.osa .error-msg{border:1px solid #fba4a5;color:#d63638;background:#fff7f7;padding:8px 16px;border-radius:3px}.osa .fold{transition:height .3s ease-in-out}.osa.loading>.inner .preloader{display:flex;text-align:center;line-height:200px;background-color:#fff9;top:0;position:absolute;height:100%;width:100%;z-index:15}.osa .inner{position:relative}.osa .inner .slide-process{transition:all .3s ease-in-out;width:100%}.osa .inner .slide-success{position:absolute;height:100%;width:100%;left:100%;top:0;transition:all .3s ease-in-out;text-align:center}.osa .inner.act-success .slide-process{margin-left:-100%}.osa .inner.act-success .slide-success{display:flex;flex-direction:column;flex-wrap:wrap;justify-content:center;align-items:center;align-content:stretch;left:0}.osa .guide{border-top:1px dotted rgba(100,100,100,.2);padding:24px 0;margin:0 24px}.osa .guide ul{margin:0;padding-left:20px}.osa .guide li{position:relative}.osa .guide li:after{content:"\f12a";color:#13962e;font-family:dashicons;line-height:1;font-weight:400;font-style:normal;text-transform:none;text-rendering:auto;font-size:14px;text-align:center;position:absolute;left:-21px;top:5px;height:15px;width:15px}.osa .step{padding:24px}.osa .step:nth-child(2){padding-top:0;padding-bottom:36px}.osa .step .step-inner{padding-top:4px;padding-left:46px;position:relative}.osa .step-title{font-weight:600}.osa .step-number{position:absolute;left:0;top:5px;border:1px solid rgba(100,100,100,.2);border-radius:14px;line-height:25px;text-align:center;height:28px;width:28px;z-index:10;background-color:#fff}.osa .step.active .step-number{background-color:#135e96;color:#fff}.osa .form-group label{display:none}.osa .form-group input{width:100%}.osa .step-1{position:relative}.osa .step-1:before{content:"";position:absolute;top:60px;left:38px;width:10px;height:90%;z-index:1;border-left:1px solid rgba(100,100,100,.2)}.osa .step-1 .form-wrap,.osa .step-1 .step-text{display:none;margin-bottom:10px}.osa .step-1 .step-action{display:block}.osa .step-1.active .form-wrap{display:flex}.osa .step-1.active .step-text{display:block}.osa .step-1.active .step-action{display:none}.osa .step-1 .form-group:nth-child(1){flex:1;margin-right:12px}.osa .step-2{position:relative;overflow:hidden}.osa .step-2:before{content:"";position:absolute;top:2px;left:33px;width:10px;height:100%;z-index:1;background-color:#fff}.osa .step-2 .step-text{margin-bottom:10px}.osa .step-2 .body{overflow:hidden}.osa .step-2 .form-wrap{display:block;position:relative;max-width:250px;overflow:hidden;height:42px;margin:14px 0}.osa .step-2 .form-wrap input{background-color:transparent;border:1px solid rgba(100,100,100,.2);border-radius:4px;text-align:center;height:36px;line-height:36px;font-size:22px;padding:0}.osa .step-2 .form-wrap input:focus{outline:none}.osa .step-2 .form-wrap .form-group{position:absolute;height:100%;width:100%;z-index:2}.osa .step-2 .body.fold{height:0px}.osa .step-2 .box-wrap{z-index:1;position:absolute;top:0;left:0;width:100%;height:100%;display:flex;flex-wrap:wrap}.osa .step-2 .box-wrap div{height:36px;width:30px;margin:0 6px;padding:2px 0;display:inline-block;cursor:pointer}.osa .step-2 .box-wrap div:nth-child(1){margin-left:0}.osa .step-2 .box-wrap div:nth-child(6){margin-right:0}.osa .step-2 .box-wrap div.active{border-color:#000}.osa #otp{font-size:22px;letter-spacing:29px;padding:0 0 0 8px;font-family:JetBrains Mono,monospace}.attribution{text-align:center}.attribution *{font-size:10px;text-decoration:none;color:#64646499}.preloader{display:none;flex-direction:row;flex-wrap:nowrap;justify-content:center;align-items:center;align-content:stretch}.lds-dual-ring{display:inline-block;width:80px;height:80px}.lds-dual-ring:after{content:" ";display:block;width:56px;height:56px;margin:8px;border-radius:50%;border:6px solid #135e96;border-color:#135e96 transparent #135e96 transparent;animation:lds-dual-ring 1.2s linear infinite}@keyframes lds-dual-ring{0%{transform:rotate(0)}to{transform:rotate(360deg)}}

        </script>';
    }
}