<?php

namespace OneSender\Uncanny\Modules\Ajax;

defined('ABSPATH') or die('No direct access allowed to this file');

use Valitron\Validator;

class Update_Settings {

	public function response() {
        $input = osun_get_input_json();

        list( $success, $errors, $input ) = $this->validate( $input );
        if ( !$success ) {
            $error_message = osun_collect($errors)->map(function($key, $item) {
                if (is_array($item)) {
                    return implode('. ', $item);
                }

                return $item;
            })->toArray();


            return wp_send_json([
                'success' => false,
                'message' => trim(implode('. ', $error_message)),
                'errors' => $errors,
            ]);

        }

        osun_set_option('onesender_api_url', $input['api_url']);
        osun_set_option('onesender_api_key', $input['api_key']);

        $output = [
            'success' => true,
            'message' => 'Settings updated',
            'data' => [
                'setting' => [
                    'api_url' => $input['api_url'],
                    'api_key' => $input['api_key'],
                ],
            ],
        ];

        return wp_send_json( $output );
	}


    public function validate( $input ) {
        $v = new Validator( $input );

        $v->rule( 'required', [
            'api_key',
            'api_url',
            'nonce', 
        ] );

        $v->rule( 'url', 'api_url' );

        return array( $v->validate(), $v->errors(), $input );
    }
}