<?php

use Uncanny_Automator\Recipe;

use OneSender\Uncanny\Wasender;

class Onesender_Send_Message {
	use Recipe\Actions;

	public function __construct() {
		$this->setup_action();
	}

	protected function setup_action() {
		$this->set_integration( 'ONESENDER' );
		$this->set_action_code( 'ONESENDER_SEND_MESSAGE' );
		$this->set_action_meta( 'ONESENDER_RECIPIENT' );
		$this->set_requires_user( false );

		$this->set_sentence( sprintf( esc_attr__( 'Send a message to {{phone:%1$s}} from OneSender Integration.', 'uncanny-automator' ), $this->get_action_meta() ) );
		$this->set_readable_sentence( esc_attr__( 'Send an {{message}} from OneSender Integration', 'uncanny-automator' ) );

		$options_group = array(
			$this->get_action_meta() => array(
				Automator()->helpers->recipe->field->text(
					array(
						'option_code' => 'ONESENDER_RECIPIENT',
						'label'       => 'WhatsApp number',
						'description' => 'Gunakan format internasional. Contoh: 62812000001',
						'placeholder' => 'WhatsApp number',
						'input_type'  => 'text',
						'default'     => '',
					)
				),
				Automator()->helpers->recipe->field->text(
					array(
						'option_code' => 'ONESENDER_MESSAGE',
						'label'       => 'Template pesan',
						'description' => 'Sample description',
						'placeholder' => 'Message',
						'input_type'  => 'textarea',
						'default'     => 'Hello',
					)
				),
			)
		);

		$this->set_options_group( $options_group );

		$this->register_action();
	}

	protected function process_action( $user_id, $action_data, $recipe_id, $args, $parsed ) {
		$recipients = $this->get_recipients(  $user_id, $action_data, $recipe_id, $args, $parsed  );
		$message 	= $this->get_message(  $user_id, $action_data, $recipe_id, $args, $parsed  );

		if ( count( $recipients ) == 0 || empty( $message ) ) {
			return;
		}
		
		Wasender::instance()->send( $recipients, $message );
	}

	private function get_message( $user_id, $action_data, $recipe_id, $args, $parsed ) {
		$message_string = $parsed['ONESENDER_MESSAGE']  ?? '';
		return osun_clean_message( $message_string );
	}

	private function get_recipients( $user_id, $action_data, $recipe_id, $args, $parsed ) {
		$recipient_string = $parsed['ONESENDER_RECIPIENT']  ?? '';
		$recipient_string = strip_tags( $recipient_string );
		$recipients = explode( ',', ($recipient_string) );
		$recipients = osun_collect( $recipients )->map( function( $key, $item ){
			return osun_clear_phone_number( $item );
		})->toArray();

		return $recipients;
	}
}